@@ -662,35 +662,37 @@ class Worker(Process):
 
         set_current_job(job)
 
+        extra = {"mrq_job_id": job.id, "params": job.data['params']}
+
         try:
             job.perform()
 
         except MaxConcurrencyInterrupt as e:
-            self.log.exception("Max concurrency reached: %s" % str(e))
+            self.log.exception("MRQ Max concurrency reached: %s" % str(job.data['path']), extra = extra)
             job._save_status("maxconcurrency", exception=True)
 
         except RetryInterrupt as e:
-            self.log.exception("Caught retry: %s" % str(job.data['path']))
+            self.log.exception("MRQ Caught retry: %s" % str(job.data['path']), extra = extra)
             job.save_retry(sys.exc_info()[1])
 
         except MaxRetriesInterrupt as e:
-            self.log.exception("Max retries reached: %s" % str(e))
+            self.log.exception("MRQ Max retries reached: %s" % str(job.data['path']), extra = extra)
             job._save_status("maxretries", exception=True)
 
         except AbortInterrupt as e:
-            self.log.exception("Caught abort: %s" % str(e))
+            self.log.exception("MRQ Caught abort: %s" % str(job.data['path']), extra = extra)
             job.save_abort()
 
         except TimeoutInterrupt:
-            self.log.exception("Job timeouted after %s seconds" % job.timeout)
+            self.log.exception("MRQ %s timeouted after %s seconds" % (str(job.data['path']), job.timeout), extra = extra)
             job._save_status("timeout", exception=True)
 
         except JobInterrupt as e:
-            self.log.exception("Job interrupted: %s" % str(e))
+            self.log.exception("MRQ Job interrupted: %s" % str(job.data['path']), extra = extra)
             job._save_status("interrupt", exception=True)
 
         except Exception as e:
-            self.log.exception("Job %s failed: %s" % (str(job.data['path']), str(e)))
+            self.log.exception("MRQ Job failed: %s" % str(job.data['path']), extra = extra)
             job._save_status("failed", exception=True)
 
         finally:
